@@ -1,5 +1,6 @@
 """wandb plugin for yea."""
 
+import json
 import pprint
 import re
 from typing import Any, Dict, Optional
@@ -191,7 +192,7 @@ def parse_expr(adict, state, result):
         op = k[len(OPSTR) :]
         opfunc = OPS.get(op) or OPS_FUNCS.get(op)
         if not opfunc:
-            result.append("unknown op: {}".format(op))
+            result.append(f"unknown op: {op}")
             return not result
         assert len(v) == 2, "ops need 2 parameters"
         v1 = parse_term(v[0], state, result)
@@ -202,7 +203,7 @@ def parse_expr(adict, state, result):
         else:
             f = getattr(v1, opfunc, None)
             if f is None:
-                result.append("unimplemented op: {}".format(opfunc))
+                result.append(f"unimplemented op: {opfunc}")
                 return not result
             b = f(v2)
         # hack to invert result for not_contains
@@ -210,7 +211,7 @@ def parse_expr(adict, state, result):
             b = not (b)
         if not b:
             print("invalid", k, v1, op, v2)
-            result.append("ASSERT {}: {} {} {}".format(k, v1, op, v2))
+            result.append(f"ASSERT {k}: {v1} {op} {v2}")
         return not result
     # if not isinstance(v, (str, int, float)):
     #     print("WARNING: Not sure how to parse (might be ok)")
@@ -218,7 +219,7 @@ def parse_expr(adict, state, result):
     v2 = parse_term(v, state, result)
     if v1 != v2:
         # print("ERROR: Unequal", k, v1, v2)
-        result.append("ASSERT {}: {} != {}".format(k, v1, v2))
+        result.append(f"ASSERT {k}: {v1} != {v2}")
     return not result
 
 
@@ -276,6 +277,7 @@ class YeaWandbPlugin:
             run["summary_wandb"] = parsed.summary_wandb
             run["telemetry"] = parsed.telemetry
             run["metrics"] = parsed.metrics
+            run["stats"] = parsed.stats
             run["exitcode"] = parsed.exit_code
             run["files"] = parsed.files
             run["output"] = parsed.output
@@ -297,9 +299,16 @@ class YeaWandbPlugin:
         # deprecate this
         state[":wandb:runs_len"] = len(runs)
 
+        # fill in profile info
+        if ytest and ytest._profile_file:
+            with open(ytest._profile_file) as f:
+                data = json.load(f)
+                state[":yea:profile"] = data
+
         # TODO(): yea should actually have its own checks, for now do it here
         if ytest:
             state[":yea:exit"] = ytest._retcode
+            state[":yea:time"] = ytest._time
 
         if debug:
             pp = pprint.PrettyPrinter(indent=2)
